@@ -113,55 +113,6 @@ orientation_handler(const gchar *iface, const gchar *method, GArray *args, gpoin
 	g_printerr("METHOD: %s\n", method);
 }
 
-/*
-gboolean
-check_device_position(DBusConnection *connection){
-    DBusError derror;
-    char *mode;
-    DBusMessage *message, *reply;
-
-    if (!connection){
-    	g_printerr("No connection\n");
-        return FALSE;
-    }
-
-    message = dbus_message_new_method_call(MCE_SERVICE,
-                                   MCE_REQUEST_PATH,
-                                   MCE_REQUEST_IF,
-                                   MCE_DEVICE_ORIENTATION_GET);
-
-    dbus_error_init(&derror);
-    reply = dbus_connection_send_with_reply_and_block(connection, message,
-                                                      -1, &derror);
-    dbus_message_unref(message);
-    if (dbus_error_is_set(&derror)) {
-        fprintf(stderr,"Getting device mode from MCE failed: %s", derror.message);
-        dbus_error_free(&derror);
-        return FALSE;
-    }
-
-    if (!dbus_message_get_args(reply, NULL,
-                               DBUS_TYPE_STRING, &mode,
-                               DBUS_TYPE_INVALID)) {
-        error(0, 0, "Invalid arguments for MCE get_device_orientation reply");
-        dbus_message_unref(reply);
-        return FALSE;
-    }
-
-    g_printerr("MODE: %s\n", mode);
-
-    if (!strcmp(mode, "portrait")) {
-    	dbus_message_unref(reply);
-        return TRUE;
-    } else {
-    	dbus_message_unref(reply);
-        return FALSE;
-    }
-
-}
-*/
-
-
 gboolean
 dbus_is_portrait_mode(osso_context_t* ctx)
 {
@@ -184,36 +135,11 @@ dbus_is_portrait_mode(osso_context_t* ctx)
 	}
 
 	return result;
-
-	/*
-	DBusConnection *con = osso_get_sys_dbus_connection(ctx);
-	DBusMessage *msg, *reply;
-	DBusError error;
-
-	msg = dbus_message_new_method_call(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF,
-			MCE_DEVICE_ORIENTATION_GET);
-
-	dbus_error_init(&error);
-
-	reply = dbus_connection_send_with_reply_and_block(con, msg, -1, &error);
-
-	if (dbus_error_is_set(&error)) {
-		g_printerr("ERROR: Failed: %s\n", error.message);
-	}
-
-	if (reply == NULL) {
-		g_printerr("ERROR: Reply is NULL\n");
-	}
-
-	gchar *mode;
-	dbus_message_get_args(reply, NULL, DBUS_TYPE_STRING, &mode, DBUS_TYPE_INVALID);
-
-	g_printerr("MODE: %s \n", mode);
-*/
-
 }
 #endif
 
+
+
 int
 main (int argc, char *argv[])
 {
@@ -276,27 +202,6 @@ main (int argc, char *argv[])
 	  search_window_open();
   }
 
-
-
-  /*******/
-  /*
-  print_note_as_json(note);
-  JsonNode *node = get_json_object_from_note(note);
-  Note *xnote = get_note_from_json_object(node);
-  g_printerr("### %s \n", xnote->guid);
-  g_printerr("### %s \n", xnote->title);
-  g_printerr("### %f \n", xnote->content_version);
-  g_printerr("### %f \n", xnote->version);
-  g_printerr("### %i \n", xnote->last_change_date);
-
-  GList *tags = note->tags;
-  while (tags != NULL) {
-	  g_printerr("TAG %s \n", (gchar*)tags->data);
-	  tags = tags->next;
-  }
-  */
-  /*********/
-
   gtk_main();
 
   cleanup();
