@@ -73,17 +73,17 @@ void handle_start_element(xmlTextReader *reader, Note *note);
 /**
  * Initializes the storage backend. E.g. conntect to a database,
  * create file paths etc.
- * 
+ *
  * user_data: Stuff like hostname, username, password, etc...
  */
 void storage_initialize(gpointer user_data)
 {
-	
+
 	/* Init XmlParser here. If possible, then maybe we save time
 	 * if we don't always recreate it
 	 */
 	/* We do nothing here. We share the xml parser with the content parser */
-	
+
 }
 
 /**
@@ -104,9 +104,9 @@ void handle_start_element(xmlTextReader *reader, Note *note)
 	gchar *value = xmlTextReaderReadString(reader);
 	gchar *attr_value = NULL;
 	XmlTag tag = string_to_enum(name);
-	
+
 	switch (tag) {
-	
+
 	case NOTE:
 		attr_value = xmlTextReaderGetAttribute(reader, BAD_CAST "version");
 		if (attr_value != NULL) {
@@ -116,11 +116,11 @@ void handle_start_element(xmlTextReader *reader, Note *note)
 		} else {
 			g_printerr("ERROR: Couldn't parse note version.\n");
 		}
-	
+
 	case TITLE:
 		note->title = g_strdup(value);
 		break;
-	
+
 	case NOTE_CONTENT:
 		attr_value = xmlTextReaderGetAttribute(reader, BAD_CAST "version");
 		if (attr_value != NULL) {
@@ -130,54 +130,54 @@ void handle_start_element(xmlTextReader *reader, Note *note)
 		} else {
 			g_printerr("ERROR: Couldn't parse content version.\n");
 		}
-		
+
 		note->content = (gchar*)xmlTextReaderReadOuterXml(reader);
 		break;
-		
+
 	case LAST_CHANGE_DATE:
 		note->last_change_date = get_iso8601_time_in_seconds(value);
 		break;
-		
+
 	case LAST_METADATA_CHANGE_DATE:
 		note->last_metadata_change_date = get_iso8601_time_in_seconds(value);
 		break;
-		
+
 	case CREATE_DATE:
 		note->create_date = get_iso8601_time_in_seconds(value);
 		break;
-		
+
 	case CURSOR_POSITION:
 		note->cursor_position = atoi(value);
 		break;
-		
+
 	case WIDTH:
 		note->width = atoi(value);
 		break;
-		
+
 	case HEIGHT:
 		note->height = atoi(value);
 		break;
-		
+
 	case X:
 		note->x = atoi(value);
 		break;
-		
+
 	case Y:
 		note->y = atoi(value);
 		break;
-		
+
 	case OPEN_ON_STARTUP:
 		note->open_on_startup = atoi(value);
 		break;
-		
+
 	case TAG:
 		note_add_tag(note, g_strdup(value));
 		break;
-		
+
 	default:
 		break;
 	}
-	
+
 	g_free(value);
 	g_free(attr_value);
 }
@@ -204,7 +204,7 @@ const gchar* enum_to_string(XmlTag tag)
 	case TAG:                       return TAG_TAG;
 	default:                        g_assert_not_reached();
 	}
-	
+
 }
 
 XmlTag string_to_enum(const gchar *string)
@@ -230,7 +230,7 @@ XmlTag string_to_enum(const gchar *string)
 	*/
 	return UNKNOWN;
 }
-	
+
 static
 void process_note(xmlTextReader *reader, Note *note)
 {
@@ -252,22 +252,22 @@ Note* storage_load_note(const gchar *guid)
 	Note *note;
 	gchar *filename;
 	xmlTextReader *reader;
-	
+
 	g_assert(guid != NULL);
-	
+
 	filename = g_strconcat(app_data->user_path, guid, ".note", NULL);
-	
+
 	/* We try to reuse the existing xml parser. If none exists yet, we create a new one. */
 	/*
 	if (app_data->reader == NULL) {
 		app_data->reader = xmlReaderForFile(filename, NULL, 0);
 	}
-	
+
 	if (xmlReaderNewFile(app_data->reader, filename, NULL, 0) != 0) {
 		g_printerr("ERROR: Cannot reuse xml parser. \n");
 		g_assert_not_reached();
 	}
-	
+
 	if (app_data->reader == NULL) {
 		g_printerr("ERROR: Cannot open file: %s\n", filename);
 		g_assert_not_reached();
@@ -276,23 +276,23 @@ Note* storage_load_note(const gchar *guid)
 	/* Reusing the xml parser does not work here. TODO: File a bug for libxml2 */
 	reader = xmlReaderForFile(filename, NULL, 0);
 	/*xmlReaderNewFile(reader, filename, NULL, 0);*/ /* To reproduce uncomment this line */
-	
+
 	note = note_create_new();
 	note->guid = g_strdup(guid);
-	
+
 	ret = xmlTextReaderRead(reader);
 	while (ret == 1) {
 		process_note(reader, note);
 		ret = xmlTextReaderRead(reader);
 	}
-		
+
 	if (ret != 0) {
 		g_printerr("ERROR: Failed to parse file: %s\n", filename);
 	}
-	
+
 	xmlFreeTextReader(reader);
 	g_free(filename);
-	
+
 	if (ret != 0) {
 		return NULL;
 	} else {
@@ -311,39 +311,39 @@ void write_header(xmlTextWriter *writer, Note *note)
 {
 	int rc;
 	gchar version[20];
-	
+
 	/* Enable indentation */
 	rc = xmlTextWriterSetIndent(writer, TRUE);
-	
+
 	/* Start document */
 	rc = xmlTextWriterStartDocument(writer, "1.0", "utf-8", NULL);
-	  
+
 	/* Start note element */
 	rc = xmlTextWriterStartElement(writer, BAD_CAST "note");
-	
+
 	g_sprintf(version, "%.1f", note->version);
 	rc = xmlTextWriterWriteAttribute(writer, BAD_CAST "version", BAD_CAST &version);
 	rc = xmlTextWriterWriteAttributeNS(writer, BAD_CAST "xmlns", BAD_CAST "link", NULL, BAD_CAST "http://beatniksoftware.com/tomboy/link");
 	rc = xmlTextWriterWriteAttributeNS(writer, BAD_CAST "xmlns", BAD_CAST "size", NULL, BAD_CAST "http://beatniksoftware.com/tomboy/size");
 	rc = xmlTextWriterWriteAttributeNS(writer, NULL, BAD_CAST "xmlns", NULL, BAD_CAST "http://beatniksoftware.com/tomboy");
-	  
+
 	/* Title element */
 	rc = xmlTextWriterWriteElement(writer, BAD_CAST "title", BAD_CAST note->title);
-	
+
 	/* Start text element */
 	rc = xmlTextWriterStartElement(writer, BAD_CAST "text");
 	rc = xmlTextWriterWriteAttributeNS(writer, BAD_CAST "xml", BAD_CAST "space", NULL, BAD_CAST "preserve");
 }
 
 static
-void write_footer(xmlTextWriter *writer, Note *note) 
+void write_footer(xmlTextWriter *writer, Note *note)
 {
 	int rc;
 	GList *tags;
-	
+
 	/* Enable indentation */
 	rc = xmlTextWriterSetIndent(writer, TRUE);
-		  
+
 	/* Meta data tags */
 	rc = xmlTextWriterWriteFormatElement(writer, BAD_CAST "last-change-date", "%s", get_time_in_seconds_as_iso8601(note->last_change_date));
 	rc = xmlTextWriterWriteFormatElement(writer, BAD_CAST "last-metadata-change-date", "%s", get_time_in_seconds_as_iso8601(note->last_metadata_change_date));
@@ -353,7 +353,7 @@ void write_footer(xmlTextWriter *writer, Note *note)
 	rc = xmlTextWriterWriteFormatElement(writer, BAD_CAST "height", "%i", note->height);
 	rc = xmlTextWriterWriteFormatElement(writer, BAD_CAST "x", "%i", note->x);
 	rc = xmlTextWriterWriteFormatElement(writer, BAD_CAST "y", "%i", note->y);
-	
+
 	/* Write tags */
 	tags = note->tags;
 	if (tags != NULL) {
@@ -365,7 +365,7 @@ void write_footer(xmlTextWriter *writer, Note *note)
 		}
 		rc = xmlTextWriterEndElement(writer);
 	}
-	
+
 	if (note->open_on_startup == TRUE) {
 		rc = xmlTextWriterWriteFormatElement(writer, BAD_CAST "open-on-startup", "True");
 	} else {
@@ -388,24 +388,25 @@ gboolean storage_save_note(Note *note)
 	AppData *app_data = app_data_get();
 	xmlTextWriter *writer;
 	gchar *filename;
-	
+
 	g_assert(note->guid != NULL);
-	
+
 	filename = g_strconcat(app_data->user_path, note->guid, ".note", NULL);
-	
+
 	writer = xmlNewTextWriterFilename(filename, 0);
 	if (writer == NULL) {
 		g_printerr("ERROR: XmlWriter is NULL \n");
 		return FALSE;
 	}
-	
+
 	write_header(writer, note);
 	xmlTextWriterWriteRaw(writer, note->content);
+	xmlTextWriterEndElement(writer); /* close <text> */
 	write_footer(writer, note);
-	
+
 	xmlFreeTextWriter(writer);
 	g_free(filename);
-	
+
 	return TRUE;
 }
 
@@ -415,21 +416,21 @@ gboolean storage_save_note(Note *note)
  * Free the list and the containing strings if you're done.
  */
 GList* storage_get_all_note_ids() {
-	
+
 	const gchar *filename;
 	AppData *app_data = app_data_get();
 	GDir *dir = g_dir_open(app_data->user_path, 0, NULL);
 	GList *result = NULL;
-	
+
 	while ((filename = g_dir_read_name(dir)) != NULL) {
 		if (g_str_has_suffix(filename, ".note")) {
 			gchar *guid = g_strndup(filename, g_utf8_strlen(filename, -1) - 5);
 			result = g_list_prepend(result, guid);
 		}
 	}
-	
+
 	g_dir_close(dir);
-	
+
 	return result;
 }
 
@@ -438,7 +439,7 @@ GList* storage_get_all_note_ids() {
  * Returns: TRUE when successfull, FALSE otherwise.
  */
 gboolean storage_delete_note(const gchar *guid)
-{	
+{
 	AppData *app_data = app_data_get();
 	gboolean result;
 	gchar *filename = g_strconcat(app_data->user_path, guid, ".note", NULL);
@@ -448,7 +449,7 @@ gboolean storage_delete_note(const gchar *guid)
 	} else {
 		result = TRUE;
 	}
-	
+
 	g_free(filename);
 	return result;
 }
@@ -457,7 +458,7 @@ gboolean storage_delete_note(const gchar *guid)
  * Returns the time in seconds that pass between a note modification and the
  * actual saving.
  * Note: Tomboy uses 4 seconds with its xml backend.
- */ 
+ */
 gint storage_get_save_interval()
 {
 	return 4;
